# LangChainPlus Client SDK

This package contains the Python client for interacting with the LangChainPlus platform.

LangChainPlus helps you and your team develop and evaluate language models and intelligent agents. It works
with any LLM Application, including a seamless integration with [LangChain](https://github.com/hwchase17/langchain), a widely recognized open-source framework that simplifies the process for developers to create powerful language model applications.

LangChainPlus is developed and maintained by [LangChain](https://langchain.com/), the company behind the LangChain framework.

